@@ -149,7 +149,9 @@ class SlappResponseObject:
         Ranking (number), bracket name, tournament name
         """
         result = []
-        low_ink_sources = [s for s in self.placements_for_players.get(p.guid.__str__(), []) if "low-ink-" in s]
+        low_ink_sources = [s for s in self.placements_for_players.get(p.guid.__str__(), []) if
+                           "low-ink-" in self.sources.get(s, s)]
+
         for source_id in low_ink_sources:
             source_name = self.sources[source_id]
 
